@@ -118,13 +118,19 @@ class StudiogdoApi(object):
     #
 
     def send(self, method, url, data=None,
-             content_type='application/x-www-form-urlencoded;charset=UTF-8'):
+             content_type='application/x-www-form-urlencoded;charset=UTF-8', files=None):
         """ Return the studiogdo cookies, the XML result of a studiogdo call."""
 
         headers = {"content-type": content_type}
+
         request_kwargs = {'url': '%s/%s' % (self.root_address, url),
                           'headers': headers}
 
+        # multipart
+        if content_type is None:
+            request_kwargs = {'url': '%s/%s' % (self.root_address, url)}
+
+
         # add studiogdo cookies
         if self.cookies:
             request_kwargs['cookies'] = self.cookies
@@ -138,7 +144,8 @@ class StudiogdoApi(object):
         self.params.update(data)
         data_name = "data" if method.lower() == "post" else "params"
         request_kwargs[data_name] = self.params
-
+        if files:
+            request_kwargs["files"] = files
         # request_kwargs["data"] = self.params
         # request_kwargs["params"] = self.params
 
