@@ -28,7 +28,8 @@ class SkelNode(template.Node):
             facet = renderer.render(path, t.render(context))
         elif settings.STUDIOGDO_FACET == "java":
             api = request.studiogdo_api
-            response = api.post_facet(encode(path), t.render(context), 'dom5')
+            unprocessed_skel = t.render(context)
+            response = api.post_facet(encode(path), unprocessed_skel, 'dom5')
             facet = unicode(response.content, 'utf-8')
 
         # set trace
