@@ -109,7 +109,17 @@ class SkelView(TemplateView):
 
             api = request.studiogdo_api
             entry = self.get_entry(**kwargs)
-            response = api.send(request.method.lower(), '%s.gdo' % entry, self.data)
+            if request.FILES:
+                content_type = None
+                files = {} # self.data.dict();
+                for k,v in request.FILES.iteritems():
+                    files[v.name] = v
+                    # files[k] = (v.name, v, v.content_type)
+
+            else:
+                content_type = 'application/x-www-form-urlencoded;charset=UTF-8'
+                files = None
+            response = api.send(request.method.lower(), '%s.gdo' % entry, data=self.data.dict(), content_type=content_type, files=files)
 
             # on error 412 return error message
             if response.status_code == 412:
